@@ -1,9 +1,9 @@
-# @(#)$Ident: LoadingClasses.pm 2013-11-22 15:17 pjf ;
+# @(#)$Ident: LoadingClasses.pm 2013-12-31 21:50 pjf ;
 
 package Class::Usul::TraitFor::LoadingClasses;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.33.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.34.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
 use Class::Usul::Functions  qw( ensure_class_loaded find_source throw );
@@ -11,12 +11,13 @@ use File::Basename          qw( basename );
 use File::Spec::Functions   qw( catfile );
 use Module::Pluggable::Object;
 use Scalar::Util            qw( blessed );
+use Unexpected::Functions   qw( Unspecified );
 use Moo::Role;
 
 sub build_subcomponents { # Voodo by mst. Finds and loads component subclasses
    my ($self, $base_class) = @_; my $my_class = blessed $self || $self;
 
-   $base_class or throw 'No base class specified';
+   $base_class or throw class => Unspecified, args => [ 'Base class' ];
 
   (my $dir = find_source $base_class) =~ s{ [.]pm \z }{}msx;
 
@@ -34,7 +35,7 @@ sub build_subcomponents { # Voodo by mst. Finds and loads component subclasses
 sub load_component {
    my ($self, $child, @parents) = @_;
 
-   $child or throw 'No child class specified';
+   $child or throw class => Unspecified, args => [ 'Child class' ];
 
    ## no critic
    for my $parent (reverse @parents) {
@@ -82,7 +83,7 @@ Class::Usul::TraitFor::LoadingClasses - Load classes at runtime
 
 =head1 Version
 
-This documents version v0.33.$Rev: 1 $
+This documents version v0.34.$Rev: 1 $
 
 =head1 Synopsis
 
@@ -129,8 +130,6 @@ None
 
 =over 3
 
-=item L<Class::Load>
-
 =item L<Class::Usul::Constants>
 
 =item L<Class::Usul::Functions>
@@ -161,7 +160,7 @@ Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2014 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
